@@ -1384,7 +1384,6 @@ prepare_mtab_entry(const char *spec, const char *node, const char *type,
 static void update_mtab_entry(int flags)
 {
 	unsigned long fl;
-	struct libmnt_lock *lc;
 
 	if (!mtab_update)
 		return;
@@ -1402,9 +1401,7 @@ static void update_mtab_entry(int flags)
 			create_mtab ();
 		}
 
-		lc = init_libmount_lock( mnt_update_get_filename(mtab_update) );
-		mnt_update_table(mtab_update, lc);
-		init_libmount_lock(NULL);
+		mnt_update_table(mtab_update, NULL);
 	}
 
 	mnt_free_update(mtab_update);
@@ -1442,25 +1439,8 @@ update_mtab_entry(const char *spec, const char *node, const char *type,
 			update_mtab (mnt.mnt_dir, &mnt);
 		else if (flags & MS_MOVE)
 			update_mtab(mnt.mnt_fsname, &mnt);
-		else {
-			mntFILE *mfp;
-
-			lock_mtab();
-			mfp = my_setmntent(_PATH_MOUNTED, "a+");
-			if (mfp == NULL || mfp->mntent_fp == NULL) {
-				int errsv = errno;
-				error(_("mount: can't open %s: %s"), _PATH_MOUNTED,
-				      strerror (errsv));
-			} else {
-				if ((my_addmntent (mfp, &mnt)) == 1) {
-					int errsv = errno;
-					error(_("mount: error writing %s: %s"),
-					      _PATH_MOUNTED, strerror (errsv));
-				}
-			}
-			my_endmntent(mfp);
-			unlock_mtab();
-		}
+		else
+			update_mtab(NULL, &mnt);
 	}
 	my_free(mnt.mnt_fsname);
 	my_free(mnt.mnt_dir);
@@ -1639,6 +1619,9 @@ try_mount_one (const char *spec0, const char *node0, const char *types0,
 #ifdef HAVE_LIBMOUNT_MOUNT
   mtab_opts = fix_opts_string(flags & ~MS_NOMTAB, extra_opts, user);
   mtab_flags = flags;
+
+  if (fake)
+    prepare_mtab_entry(spec, node, types, mtab_opts, mtab_flags);
 #endif
 
   block_signals (SIG_BLOCK);
